@@ -34,7 +34,7 @@ from calculate.lib.utils.common import (getVideoFromXorgLog,
                                         getVideoFromVendor, getInstalledVideo,
                                         CmdlineParams)
 from calculate.lib.utils.video import get_edid_data, EdidInfoError, EdidInfo
-from calculate.install.distr import DistributiveError
+from ..distr import DistributiveError
 import fcntl
 import struct
 from collections import OrderedDict
@@ -91,8 +91,7 @@ class ResolutionVariable(VideoVariable):
                        "1600x900", "1600x1200", "2048x1152", "2560x1440",
                        "2560x1600"]
         if self.fbres:
-            return map(lambda x: "%s-32" % x,
-                       resolutions)
+            return ["%s-32" % x for x in resolutions]
         else:
             return resolutions
 
@@ -183,7 +182,7 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
         return []
 
     def humanReadable(self):
-        return map(lambda x: self.driver_names.get(x, x), self.Get())
+        return [self.driver_names.get(x, x) for x in self.Get()]
 
 
 class VariableOsX11KmsVideoDrv(ReadonlyVariable):
@@ -219,9 +218,9 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
         if self.Get('os_install_x11_server_set') == 'on':
             values = self.Get('os_install_x11_video_available')
         else:
-            values = self.nox_video_drivers()
-        return map(lambda x: (x, self.driver_names.get(x, x)),
-                   (x for x in self.driver_names.keys() if x in values))
+            values = self.nox_video_drivers()        
+        return [(x, self.driver_names.get(x, x)) for x 
+            in [y for y in self.driver_names.keys() if y in values]]
 
     def get(self):
         if self.Get('os_install_x11_server_set') == 'on':
@@ -249,7 +248,7 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
                     return drv
             return self.default_video
         else:
-            for drv in map(lambda x: x[0], self.choice()):
+            for drv in (x[0] for x in self.choice()):
                 refcnt = device.sysfs.read(
                     device.sysfs.Path.Module, drv, "refcnt").strip()
                 if refcnt.isdigit() and int(refcnt) > 0:
@@ -417,7 +416,7 @@ class VariableClGrubImageHash(ReadonlyVariable):
     theme_data = "/etc/grub.d/05_theme"
 
     def get_image_md5(self, source):
-        return hashlib.md5(readFile(source)).hexdigest()
+        return hashlib.md5(readFile(source, binary=True)).hexdigest()
 
     def get_config_md5(selfself, source):
         return hashlib.md5(readFileEx(source, grab=True)).hexdigest()
